@@ -365,4 +365,14 @@ class ListingResource:
         json = await self.session.async_request(endpoint, params=RequestEncodingMixin._encode_params(params))
 
         return Response[Listing](**json)
-    
\ No newline at end of file
+    
+    
+    async def aget_listings_by_listing_ids(self, listing_ids: List[int], includes: str = ""):
+        params = {
+            "listing_ids":",".join(list(map(str, listing_ids))),
+            "includes":includes
+        }
+        endpoint = "listings/batch"
+        
+        response = await self.session.async_request(endpoint, params=RequestEncodingMixin._encode_params(params))
+        return Response[Listing](**response)
\ No newline at end of file
